@@ -3,9 +3,11 @@
 #' Tools for extracting and processing eBird data from the eBird Basic Dataset 
 #' (EBD).
 #'
-#' @name auk
-#' @docType package
-#' @importFrom stringr str_interp
-#' @importFrom rlang .data
 #' @keywords internal
+"_PACKAGE"
+
+## usethis namespace: start
+#' @importFrom rlang .data
+#' @importFrom stringr str_interp
+## usethis namespace: end
 NULL
