@@ -21,16 +21,18 @@ get_col_types <- function(header) {
   col_types <- c(
     "GLOBAL UNIQUE IDENTIFIER" = "character",
     "LAST EDITED DATE" = "character",
-    "TAXONOMIC ORDER" = "numeric",
+    "TAXONOMIC ORDER" = "integer",
     "CATEGORY" = "character",
     "COMMON NAME" = "character",
+    "TAXON CONCEPT ID" = "character",
     "SCIENTIFIC NAME" = "character",
     "SUBSPECIES COMMON NAME" = "character",
     "SUBSPECIES SCIENTIFIC NAME" = "character",
     "EXOTIC CODE" = "character",
     "OBSERVATION COUNT" = "character",
-    "BREEDING BIRD ATLAS CODE" = "character",
-    "BREEDING BIRD ATLAS CATEGORY" = "character",
+    "BREEDING CODE" = "character",
+    "BREEDING CATEGORY" = "character",
+    "BEHAVIOR CODE" = "character",
     "AGE/SEX" = "character",
     "COUNTRY" = "character",
     "COUNTRY CODE" = "character",
@@ -50,12 +52,13 @@ get_col_types <- function(header) {
     "OBSERVATION DATE" = "Date",
     "TIME OBSERVATIONS STARTED" = "character",
     "OBSERVER ID" = "character",
-    "FIRST NAME" = "character",
-    "LAST NAME" = "character",
+    "OBSERVER ORCID ID" = "character",
     "SAMPLING EVENT IDENTIFIER" = "character",
-    "PROTOCOL TYPE" = "character",
+    "OBSERVATION TYPE" = "character",
+    "PROTOCOL NAME" = "character",
     "PROTOCOL CODE" = "character",
-    "PROJECT CODE" = "character",
+    "PROJECT NAMES" = "character",
+    "PROJECT IDENTIFIERS" = "character",
     "DURATION MINUTES" = "integer",
     "EFFORT DISTANCE KM" = "numeric",
     "EFFORT AREA HA" = "numeric",
@@ -66,7 +69,7 @@ get_col_types <- function(header) {
     "APPROVED" = "logical",
     "REVIEWED" = "logical",
     "REASON" = "character",
-    "TRIP COMMENTS" = "character",
+    "CHECKLIST COMMENTS" = "character",
     "SPECIES COMMENTS" = "character")
   
   # remove any columns not in header
